@@ -40,9 +40,11 @@
 #include <gtk/gtkx.h>
 
 #include <libxfce4util/libxfce4util.h>
+#include <xfconf/xfconf.h>
 
 #include "gs-lock-plug.h"
 #include "gs-debug.h"
+#include "gs-prefs.h"
 #include "xfce-bg.h"
 #include "xfce-desktop-utils.h"
 #include "xfce4-screensaver-dialog-ui.h"
@@ -57,12 +59,8 @@
 #define GDM_FLEXISERVER_COMMAND "gdmflexiserver"
 #define GDM_FLEXISERVER_ARGS    "--startnew Standard"
 
-enum {
-    AUTH_PAGE = 0,
-};
-
 #define FACE_ICON_SIZE 48
-#define DIALOG_TIMEOUT_MSEC 60000
+#define DIALOG_TIMEOUT_SEC 60
 
 static void gs_lock_plug_finalize   (GObject         *object);
 
@@ -88,6 +86,7 @@ struct GSLockPlugPrivate {
     GtkWidget   *auth_logout_button;
 
     GtkWidget   *auth_prompt_kbd_layout_indicator;
+    GtkWidget   *keyboard_toggle;
 
     gboolean     caps_lock_on;
     gboolean     switch_enabled;
@@ -95,8 +94,6 @@ struct GSLockPlugPrivate {
     char        *logout_command;
     char        *status_message;
 
-    guint        timeout;
-
     guint        datetime_timeout_id;
     guint        cancel_timeout_id;
     guint        auth_check_idle_id;
@@ -105,6 +102,9 @@ struct GSLockPlugPrivate {
     gint         monitor_index;
 
     GList       *key_events;
+
+    GSPrefs       *prefs;
+    XfconfChannel *channel;
 };
 
 typedef struct _ResponseData ResponseData;
@@ -328,15 +328,11 @@ remove_response_idle (GSLockPlug *plug) {
 static void
 gs_lock_plug_response (GSLockPlug *plug,
                        gint        response_id) {
-    int new_response;
-
-    new_response = response_id;
-
     g_return_if_fail (GS_IS_LOCK_PLUG (plug));
 
     /* Act only on response IDs we recognize */
-    if (!(response_id == GS_LOCK_PLUG_RESPONSE_OK
-            || response_id == GS_LOCK_PLUG_RESPONSE_CANCEL)) {
+    if (!(response_id == GS_LOCK_PLUG_RESPONSE_OK ||
+          response_id == GS_LOCK_PLUG_RESPONSE_CANCEL)) {
         return;
     }
 
@@ -347,10 +343,7 @@ gs_lock_plug_response (GSLockPlug *plug,
         gtk_entry_set_text (GTK_ENTRY (plug->priv->auth_prompt_entry), "");
     }
 
-    g_signal_emit (plug,
-                   lock_plug_signals[RESPONSE],
-                   0,
-                   new_response);
+    g_signal_emit (plug, lock_plug_signals[RESPONSE], 0, response_id);
 }
 
 static gboolean
@@ -400,25 +393,21 @@ capslock_update (GSLockPlug *plug,
 static gboolean
 is_capslock_on (void) {
     GdkKeymap *keymap;
-    gboolean res;
-
-    res = FALSE;
 
     keymap = gdk_keymap_get_for_display (gdk_display_get_default());;
-    if (keymap != NULL) {
-        res = gdk_keymap_get_caps_lock_state (keymap);
-    }
+    if (keymap == NULL)
+        return FALSE;
 
-    return res;
+    return gdk_keymap_get_caps_lock_state (keymap);
 }
 
 static void
 restart_cancel_timeout (GSLockPlug *plug) {
     remove_cancel_timeout (plug);
-
-    plug->priv->cancel_timeout_id = g_timeout_add (plug->priv->timeout,
-                                                   (GSourceFunc)dialog_timed_out,
-                                                   plug);
+    plug->priv->cancel_timeout_id = g_timeout_add_seconds (
+                                       DIALOG_TIMEOUT_SEC,
+                                       (GSourceFunc)dialog_timed_out,
+                                       plug);
 }
 
 void
@@ -658,20 +647,16 @@ get_user_icon_from_accounts_service (void) {
 
 static gboolean
 set_face_image (GSLockPlug *plug) {
-    GdkPixbuf  *pixbuf = get_user_icon_from_accounts_service ();
+    char      *path;
+    GError    *error = NULL;
+    GdkPixbuf *pixbuf;
 
+    pixbuf = get_user_icon_from_accounts_service ();
     if (pixbuf == NULL) {
-        const char *homedir;
-        char       *path;
-        GError     *error = NULL;
-        homedir = g_get_home_dir ();
-        path = g_build_filename (homedir, ".face", NULL);
-
-        pixbuf = gdk_pixbuf_new_from_file_at_scale (path, 80, 80, FALSE,
-                                                    &error);
+        path = g_build_filename (g_get_home_dir(), ".face", NULL);
+        pixbuf = gdk_pixbuf_new_from_file_at_scale (path, 80, 80, FALSE, &error);
         if (pixbuf == NULL) {
-            g_warning ("Could not load the user avatar: %s",
-                       error->message);
+            g_warning ("Could not load the user avatar: %s", error->message);
             g_error_free (error);
             return FALSE;
         }
@@ -1201,29 +1186,6 @@ entry_key_press (GtkWidget   *widget,
     return TRUE;
 }
 
-/* adapted from gtk_dialog_add_button */
-static GtkWidget *
-gs_lock_plug_add_button (GSLockPlug  *plug,
-                         GtkWidget   *action_area,
-                         const gchar *button_text) {
-    GtkWidget *button;
-
-    g_return_val_if_fail (GS_IS_LOCK_PLUG (plug), NULL);
-    g_return_val_if_fail (button_text != NULL, NULL);
-
-    button = gtk_button_new_with_label (button_text);
-
-    gtk_widget_set_can_default (button, TRUE);
-
-    gtk_widget_show (button);
-
-    gtk_box_pack_end (GTK_BOX (action_area),
-                      button,
-                      FALSE, TRUE, 0);
-
-    return button;
-}
-
 static char *
 get_user_display_name (void) {
     const char *name;
@@ -1260,40 +1222,6 @@ get_user_name (void) {
     return utf8_name;
 }
 
-static void
-create_page_one_buttons (GSLockPlug *plug) {
-    gs_profile_start ("page one buttons");
-
-    plug->priv->auth_switch_button =  gs_lock_plug_add_button (GS_LOCK_PLUG (plug),
-                                      plug->priv->auth_action_area,
-                                      _("S_witch User..."));
-    gtk_button_box_set_child_secondary (GTK_BUTTON_BOX (plug->priv->auth_action_area),
-                                        plug->priv->auth_switch_button,
-                                        TRUE);
-    gtk_widget_set_focus_on_click (GTK_WIDGET (plug->priv->auth_switch_button), FALSE);
-    gtk_widget_set_no_show_all (plug->priv->auth_switch_button, TRUE);
-
-    plug->priv->auth_logout_button =  gs_lock_plug_add_button (GS_LOCK_PLUG (plug),
-                                      plug->priv->auth_action_area,
-                                      _("Log _Out"));
-    gtk_widget_set_focus_on_click (GTK_WIDGET (plug->priv->auth_logout_button), FALSE);
-    gtk_widget_set_no_show_all (plug->priv->auth_logout_button, TRUE);
-
-    plug->priv->auth_cancel_button =  gs_lock_plug_add_button (GS_LOCK_PLUG (plug),
-                                      plug->priv->auth_action_area,
-                                      _("_Cancel"));
-    gtk_widget_set_focus_on_click (GTK_WIDGET (plug->priv->auth_cancel_button), FALSE);
-
-    plug->priv->auth_unlock_button =  gs_lock_plug_add_button (GS_LOCK_PLUG (plug),
-                                      plug->priv->auth_action_area,
-                                      _("_Unlock"));
-    gtk_widget_set_focus_on_click (GTK_WIDGET (plug->priv->auth_unlock_button), FALSE);
-
-    gtk_window_set_default (GTK_WINDOW (plug), plug->priv->auth_unlock_button);
-
-    gs_profile_end ("page one buttons");
-}
-
 /* adapted from MDM */
 static char *
 expand_string (const char *text) {
@@ -1416,86 +1344,6 @@ expand_string_for_label (GtkWidget *label) {
     g_free (str);
 }
 
-static void
-create_page_one (GSLockPlug *plug) {
-    GtkWidget *vbox;
-    GtkWidget *vbox2;
-    GtkWidget *hbox;
-    char      *str;
-
-    gs_profile_start ("page one");
-
-    vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
-    gtk_widget_set_halign (GTK_WIDGET (vbox),
-                           GTK_ALIGN_CENTER);
-    gtk_widget_set_valign (GTK_WIDGET (vbox),
-                           GTK_ALIGN_CENTER);
-
-    vbox2 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-    gtk_box_pack_start (GTK_BOX (vbox), vbox2, FALSE, FALSE, 0);
-
-    plug->priv->auth_face_image = gtk_image_new ();
-    gtk_box_pack_start (GTK_BOX (vbox), plug->priv->auth_face_image, TRUE, TRUE, 0);
-    gtk_widget_set_halign (plug->priv->auth_face_image, GTK_ALIGN_CENTER);
-    gtk_widget_set_valign (plug->priv->auth_face_image, GTK_ALIGN_END);
-
-    vbox2 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-    gtk_box_pack_start (GTK_BOX (vbox), vbox2, FALSE, FALSE, 0);
-
-    str = g_strdup ("<span size=\"x-large\">%R</span>");
-    plug->priv->auth_realname_label = gtk_label_new (str);
-    g_free (str);
-    expand_string_for_label (plug->priv->auth_realname_label);
-    gtk_label_set_xalign (GTK_LABEL (plug->priv->auth_realname_label), 0.5);
-    gtk_label_set_yalign (GTK_LABEL (plug->priv->auth_realname_label), 0.5);
-    gtk_label_set_use_markup (GTK_LABEL (plug->priv->auth_realname_label), TRUE);
-    gtk_box_pack_start (GTK_BOX (vbox2), plug->priv->auth_realname_label, FALSE, FALSE, 0);
-
-    /* To translators: This expands to USERNAME on HOSTNAME */
-    str = g_strdup_printf ("<span size=\"small\">%s</span>", _("%U on %h"));
-    plug->priv->auth_username_label = gtk_label_new (str);
-    g_free (str);
-    expand_string_for_label (plug->priv->auth_username_label);
-    gtk_label_set_xalign (GTK_LABEL (plug->priv->auth_realname_label), 0.5);
-    gtk_label_set_yalign (GTK_LABEL (plug->priv->auth_realname_label), 0.5);
-    gtk_label_set_use_markup (GTK_LABEL (plug->priv->auth_username_label), TRUE);
-    gtk_box_pack_start (GTK_BOX (vbox2), plug->priv->auth_username_label, FALSE, FALSE, 0);
-
-    vbox2 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-    gtk_box_pack_start (GTK_BOX (vbox), vbox2, TRUE, TRUE, 0);
-
-    hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
-    gtk_box_pack_start (GTK_BOX (vbox2), hbox, FALSE, FALSE, 0);
-
-    plug->priv->auth_prompt_label = gtk_label_new (_("Please enter your password."));
-    gtk_box_pack_start (GTK_BOX (hbox), plug->priv->auth_prompt_label, FALSE, FALSE, 0);
-
-    plug->priv->auth_prompt_entry = gtk_entry_new ();
-    gtk_box_pack_start (GTK_BOX (hbox), plug->priv->auth_prompt_entry, TRUE, TRUE, 0);
-
-    gtk_label_set_mnemonic_widget (GTK_LABEL (plug->priv->auth_prompt_label),
-                                   plug->priv->auth_prompt_entry);
-
-    /* Status text */
-
-    plug->priv->auth_message_label = gtk_label_new (NULL);
-    gtk_box_pack_start (GTK_BOX (vbox), plug->priv->auth_message_label,
-                        FALSE, FALSE, 0);
-    /* Buttons */
-    plug->priv->auth_action_area = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
-
-    gtk_button_box_set_layout (GTK_BUTTON_BOX (plug->priv->auth_action_area),
-                               GTK_BUTTONBOX_END);
-
-    gtk_box_pack_end (GTK_BOX (vbox), plug->priv->auth_action_area,
-                      FALSE, TRUE, 0);
-    gtk_widget_show (plug->priv->auth_action_area);
-
-    create_page_one_buttons (plug);
-
-    gs_profile_end ("page one");
-}
-
 static void
 unlock_button_clicked (GtkButton  *button,
                        GSLockPlug *plug) {
@@ -1529,13 +1377,13 @@ get_draw_dimensions(GSLockPlug *plug,
                     gint       *screen_width,
                     gint       *screen_height,
                     gint       *monitor_width,
-                    gint       *monitor_height) {
+                    gint       *monitor_height,
+                    gint       *scale) {
     GdkWindow    *window;
     GdkDisplay   *display;
     GdkScreen    *screen;
     GdkMonitor   *monitor;
     GdkRectangle  geometry;
-    gint          scale;
 
     window = gtk_widget_get_window (GTK_WIDGET(plug));
     if (window != NULL) {
@@ -1544,7 +1392,7 @@ get_draw_dimensions(GSLockPlug *plug,
         display = gdk_display_get_default();
     }
     screen = gdk_display_get_default_screen(display);
-    scale = gdk_window_get_scale_factor(gdk_screen_get_root_window(screen));
+    *scale = gdk_window_get_scale_factor(gdk_screen_get_root_window(screen));
 
     monitor = gdk_display_get_monitor (display, plug->priv->monitor_index);
     if (!monitor) {
@@ -1560,27 +1408,38 @@ get_draw_dimensions(GSLockPlug *plug,
     xfce_bg_load_from_preferences(bg, monitor);
 
     gdk_monitor_get_geometry(monitor, &geometry);
-    *monitor_width = geometry.width / scale;
-    *monitor_height = geometry.height / scale;
-    *screen_width = WidthOfScreen(gdk_x11_screen_get_xscreen(screen)) / scale;
-    *screen_height = HeightOfScreen(gdk_x11_screen_get_xscreen(screen)) / scale;
+    *monitor_width = geometry.width;
+    *monitor_height = geometry.height;
+    *screen_width = WidthOfScreen(gdk_x11_screen_get_xscreen(screen));
+    *screen_height = HeightOfScreen(gdk_x11_screen_get_xscreen(screen));
 }
 
 static void
 redraw_background (GSLockPlug *plug) {
     XfceBG    *bg;
     GdkPixbuf *pixbuf;
-    gint       screen_width, screen_height, monitor_width, monitor_height;
+    gint       screen_width, screen_height, monitor_width, monitor_height, scale;
 
     gs_debug ("Redrawing background");
     bg = xfce_bg_new();
-    get_draw_dimensions(plug, bg, &screen_width, &screen_height, &monitor_width, &monitor_height);
-    pixbuf = xfce_bg_get_pixbuf(bg, screen_width, screen_height, monitor_width, monitor_height);
+    get_draw_dimensions(plug, bg, &screen_width, &screen_height, &monitor_width, &monitor_height, &scale);
+    pixbuf = xfce_bg_get_pixbuf(bg, screen_width, screen_height, monitor_width, monitor_height, scale);
     gtk_image_set_from_pixbuf(GTK_IMAGE(plug->priv->background_image), pixbuf);
 }
 
+static void
+keyboard_toggled_cb (GtkToggleButton *button,
+                    gpointer        *user_data) {
+    GSLockPlug *plug = GS_LOCK_PLUG (user_data);
+
+    gboolean active = gtk_toggle_button_get_active (button);
+    xfconf_channel_set_bool (plug->priv->channel, KEY_KEYBOARD_DISPLAYED, active);
+
+    gtk_widget_grab_focus (plug->priv->auth_prompt_entry);
+}
+
 static gboolean
-load_theme (GSLockPlug *plug) {
+gs_lock_plug_add_login_window (GSLockPlug *plug) {
     GtkBuilder *builder;
     GtkWidget  *lock_overlay;
     GtkWidget  *lock_panel;
@@ -1595,6 +1454,9 @@ load_theme (GSLockPlug *plug) {
         return FALSE;
     }
 
+    plug->priv->prefs = gs_prefs_new ();
+    plug->priv->channel = xfconf_channel_get (SETTINGS_XFCONF_CHANNEL);
+
     lock_overlay = GTK_WIDGET(gtk_builder_get_object(builder, "lock-overlay"));
     lock_panel = GTK_WIDGET(gtk_builder_get_object(builder, "lock-panel"));
     lock_dialog = GTK_WIDGET(gtk_builder_get_object(builder, "login_window"));
@@ -1629,6 +1491,15 @@ load_theme (GSLockPlug *plug) {
     plug->priv->auth_capslock_label = GTK_WIDGET (gtk_builder_get_object(builder, "auth-capslock-label"));
     plug->priv->auth_message_label = GTK_WIDGET (gtk_builder_get_object(builder, "auth-status-label"));
 
+    plug->priv->keyboard_toggle = GTK_WIDGET (gtk_builder_get_object(builder, "keyboard-toggle"));
+    if (plug->priv->prefs->keyboard_enabled) {
+        gtk_widget_show (plug->priv->keyboard_toggle);
+        gtk_widget_set_no_show_all (plug->priv->keyboard_toggle, FALSE);
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (plug->priv->keyboard_toggle), plug->priv->prefs->keyboard_displayed);
+        g_signal_connect (GTK_TOGGLE_BUTTON (plug->priv->keyboard_toggle), "toggled",
+                          G_CALLBACK (keyboard_toggled_cb), plug);
+    }
+
     /* Placeholder for the keyboard indicator */
     plug->priv->auth_prompt_kbd_layout_indicator = GTK_WIDGET (
             gtk_builder_get_object(builder, "auth-prompt-kbd-layout-indicator"));
@@ -1664,24 +1535,7 @@ gs_lock_plug_init (GSLockPlug *plug) {
 
     clear_clipboards (plug);
 
-    GtkStyleContext *context;
-
-    context = gtk_widget_get_style_context (GTK_WIDGET (plug));
-    gtk_style_context_add_class (context, "login_window");
-
-    if (!load_theme (plug)) {
-        gs_debug ("Unable to load theme!");
-
-        plug->priv->vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-        gtk_container_add (GTK_CONTAINER (plug), plug->priv->vbox);
-
-        /* Page 1 */
-
-        create_page_one (plug);
-
-        date_time_update (plug);
-        gtk_widget_show_all (plug->priv->vbox);
-    }
+    gs_lock_plug_add_login_window (plug);
     plug->priv->datetime_timeout_id = g_timeout_add_seconds (60, (GSourceFunc) date_time_update, plug);
 
     /* Layout indicator */
@@ -1735,8 +1589,6 @@ gs_lock_plug_init (GSLockPlug *plug) {
         }
     }
 
-    plug->priv->timeout = DIALOG_TIMEOUT_MSEC;
-
     g_signal_connect (plug, "key_press_event",
                       G_CALLBACK (entry_key_press), plug);
 
@@ -1791,6 +1643,12 @@ gs_lock_plug_finalize (GObject *object) {
 
     g_free (plug->priv->logout_command);
 
+    g_free (plug->priv->prefs);
+    plug->priv->prefs = NULL;
+
+    g_free (plug->priv->channel);
+    plug->priv->channel = NULL;
+
     remove_response_idle (plug);
     remove_cancel_timeout (plug);
     remove_datetime_timeout (plug);
