@@ -91,18 +91,53 @@ G_DEFINE_TYPE_WITH_PRIVATE (GSManager, gs_manager, G_TYPE_OBJECT)
 static void         remove_deepsleep_idle   (GSManager *manager);
 static gboolean     deepsleep_idle          (GSManager *manager);
 static void         add_deepsleep_idle      (GSManager *manager);
+static void
+gs_manager_create_windows_for_display       (GSManager  *manager,
+                                             GdkDisplay *display);
+
+static gboolean
+gs_manager_is_real_monitor (GdkMonitor *monitor) {
+    // avoiding some weird gdk bug
+    // federico> avb: or if you don't care about a little unexplained messiness,
+    //                just discard monitors where both fields are null? :)
+    if (gdk_monitor_get_manufacturer(monitor) == NULL && gdk_monitor_get_model(monitor) == NULL)
+        return FALSE;
+    return TRUE;
+}
+
+static int
+gs_manager_get_n_monitors (GdkDisplay *display) {
+    // Since gdk_display_get_n_monitors return wrong monitor count
+    // this is a workaround for the problem
+    int n_monitors;
+    int i, count = 0;
+
+    n_monitors = gdk_display_get_n_monitors (display);
+    for (i = 0; i < n_monitors; i++) {
+        GdkMonitor *monitor = gdk_display_get_monitor(display, i);
+        if (gs_manager_is_real_monitor (monitor))
+            count++;
+    }
+    return count;
+}
 
 static gint
 manager_get_monitor_index (GdkMonitor *this_monitor) {
-    GdkDisplay *display = gdk_monitor_get_display (this_monitor);
+    GdkDisplay *display;
     gint        idx;
 
+    if (!gs_manager_is_real_monitor (this_monitor))
+        return -1;
+
+    display = gdk_monitor_get_display (this_monitor);
+
     for (idx = 0; idx < gdk_display_get_n_monitors (display); idx++) {
         GdkMonitor *monitor = gdk_display_get_monitor (display, idx);
         if (monitor == this_monitor)
             return idx;
     }
-    return 0;
+
+    return -1;
 }
 
 static void
@@ -522,17 +557,19 @@ activate_dpms_timeout (GSManager *manager) {
     BOOL state;
     CARD16 power_level;
 
-    if (DPMSInfo(gdk_x11_get_default_xdisplay(), &power_level, &state)) {
-        if (state) {
-            if (power_level == DPMSModeOn) {
-                gs_debug("DPMS: On -> Standby");
-                DPMSForceLevel (gdk_x11_get_default_xdisplay(), DPMSModeStandby);
-                remove_dpms_timer (manager);
-                add_dpms_timer (manager, manager->priv->prefs->dpms_off_timeout);
-                return FALSE;
-            } else if (power_level == DPMSModeStandby || power_level == DPMSModeSuspend) {
-                gs_debug("DPMS: %s -> Off", power_level == DPMSModeStandby ? "Standby" : "Suspend");
-                DPMSForceLevel (gdk_x11_get_default_xdisplay(), DPMSModeOff);
+    if (manager->priv->active) {
+        if (DPMSInfo(gdk_x11_get_default_xdisplay(), &power_level, &state)) {
+            if (state) {
+                if (power_level == DPMSModeOn) {
+                    gs_debug("DPMS: On -> Standby");
+                    DPMSForceLevel (gdk_x11_get_default_xdisplay(), DPMSModeStandby);
+                    remove_dpms_timer (manager);
+                    add_dpms_timer (manager, manager->priv->prefs->dpms_off_timeout);
+                    return FALSE;
+                } else if (power_level == DPMSModeStandby || power_level == DPMSModeSuspend) {
+                    gs_debug("DPMS: %s -> Off", power_level == DPMSModeStandby ? "Standby" : "Suspend");
+                    DPMSForceLevel (gdk_x11_get_default_xdisplay(), DPMSModeOff);
+                }
             }
         }
     }
@@ -558,7 +595,7 @@ add_dpms_timer (GSManager *manager,
     if (timeout == 0)
         return;
 
-    gs_debug ("Scheduling DPMS change after screensaver is idling for %i minute", timeout);
+    gs_debug ("Scheduling DPMS change after screensaver is idling for %i minute(s)", timeout);
     manager->priv->dpms_timeout_id = g_timeout_add (timeout * 60000,
                                                     (GSourceFunc)activate_dpms_timeout,
                                                     manager);
@@ -598,7 +635,7 @@ find_window_at_pointer (GSManager *manager) {
     GdkDevice  *device;
     GdkMonitor *monitor;
     int         x, y;
-    GSList     *window;
+    GSList     *window = NULL;
 
     display = gdk_display_get_default ();
 
@@ -607,16 +644,22 @@ find_window_at_pointer (GSManager *manager) {
     monitor = gdk_display_get_monitor_at_point (display, x, y);
 
     /* Find the gs-window that is on that monitor */
-    window = g_slist_nth (manager->priv->windows, manager_get_monitor_index (monitor));
+    if (gs_manager_is_real_monitor (monitor))
+        window = g_slist_nth (manager->priv->windows, manager_get_monitor_index (monitor));
+
     if (window == NULL) {
         gs_debug ("WARNING: Could not find the GSWindow for display %s",
                   gdk_display_get_name (display));
+
         /* bail if there are no windows available */
         if (manager->priv->windows == NULL)
             return NULL;
 
         /* take the first one */
         window = manager->priv->windows->data;
+        if (window->data == NULL || !GS_IS_WINDOW (GS_WINDOW (window->data))) {
+            return NULL;
+        }
     } else {
         gs_debug ("Requesting unlock for display %s",
                   gdk_display_get_name (display));
@@ -940,6 +983,9 @@ gs_manager_create_window_for_monitor (GSManager  *manager,
     GSWindow    *window;
     GdkRectangle rect;
 
+    if (!gs_manager_is_real_monitor (monitor))
+        return;
+
     if (g_slist_nth (manager->priv->windows, manager_get_monitor_index(monitor))) {
         gs_debug ("Found already created window for Monitor %d", manager_get_monitor_index(monitor));
         return;
@@ -962,28 +1008,87 @@ gs_manager_create_window_for_monitor (GSManager  *manager,
     }
 }
 
+static GSList *
+add_overlays (GSManager *manager) {
+    GSList     *l;
+    GSList     *windows = NULL;
+
+    gs_debug("Reconfiguring monitors, adding overlays");
+
+    l = manager->priv->windows;
+    while (l != NULL) {
+        GdkMonitor *this_monitor;
+        GSList     *next = l->next;
+        GtkWidget  *window;
+        GdkRectangle rect;
+
+        this_monitor = gs_window_get_monitor (GS_WINDOW (l->data));
+
+        // Display an overlay to protect each window as we redraw everything
+        if (GDK_IS_MONITOR (this_monitor)) {
+            window = gtk_window_new (GTK_WINDOW_POPUP);
+            gdk_monitor_get_geometry (this_monitor, &rect);
+            gtk_window_move (GTK_WINDOW (window), rect.x, rect.y);
+            gtk_window_resize (GTK_WINDOW (window), rect.width, rect.height);
+            gtk_widget_show (GTK_WIDGET (window));
+            windows = g_slist_append (windows, window);
+        }
+
+        l = next;
+    }
+
+    return windows;
+}
+
+static gboolean
+remove_overlays (GSList *windows) {
+    gs_debug("Done reconfiguring monitors, removing overlays");
+    g_slist_free_full (windows, (GDestroyNotify) gtk_widget_destroy);
+    return FALSE;
+}
+
+static void
+reconfigure_monitors (GdkDisplay *display,
+                      GSManager  *manager) {
+    GSList     *l;
+    GSList     *windows;
+
+    windows = add_overlays (manager);
+
+    /* Remove lost windows */
+    l = manager->priv->windows;
+    while (l != NULL) {
+        GSList     *next = l->next;
+
+        manager_maybe_stop_job_for_window (manager, GS_WINDOW (l->data));
+        g_hash_table_remove (manager->priv->jobs, l->data);
+        gs_window_destroy (GS_WINDOW (l->data));
+        manager->priv->windows = g_slist_delete_link (manager->priv->windows, l);
+
+        l = next;
+    }
+
+    gs_manager_create_windows_for_display (manager, display);
+
+    gs_manager_request_unlock (manager);
+
+    g_timeout_add (2000,
+                   (GSourceFunc)remove_overlays,
+                   windows);
+}
+
 static void
 on_display_monitor_added (GdkDisplay *display,
                           GdkMonitor *monitor,
                           GSManager  *manager) {
-    GSList     *l;
     int         n_monitors;
 
-    n_monitors = gdk_display_get_n_monitors (display);
+    n_monitors = gs_manager_get_n_monitors (display);
 
     gs_debug ("Monitor %s added on display %s, now there are %d",
               gdk_monitor_get_model(monitor), gdk_display_get_name (display), n_monitors);
 
-    l = g_slist_nth (manager->priv->windows, manager_get_monitor_index (monitor));
-    if (l) {
-        gs_debug ("Found window for this Monitor");
-        gs_window_set_monitor (GS_WINDOW (l->data), monitor);
-    } else {
-        gs_debug("Creating new window for Monitor %s", gdk_monitor_get_model (monitor));
-        gs_manager_create_window_for_monitor(manager, monitor);
-        l = g_slist_nth (manager->priv->windows, manager_get_monitor_index (monitor));
-    }
-    gs_window_request_unlock (l->data);
+    reconfigure_monitors (display, manager);
 }
 
 static void
@@ -992,10 +1097,12 @@ on_display_monitor_removed (GdkDisplay *display,
                             GSManager  *manager) {
     int         n_monitors;
 
-    n_monitors = gdk_display_get_n_monitors (display);
+    n_monitors = gs_manager_get_n_monitors (display);
 
     gs_debug ("Monitor %p removed on display %s, now there are %d",
               monitor, gdk_display_get_name (display), n_monitors);
+
+    reconfigure_monitors (display, manager);
 }
 
 static void
@@ -1133,6 +1240,7 @@ remove_job (GSJob *job) {
 
 static gboolean
 gs_manager_activate (GSManager *manager) {
+    GSList     *windows;
     gboolean    res;
 
     g_return_val_if_fail (manager != NULL, FALSE);
@@ -1159,8 +1267,14 @@ gs_manager_activate (GSManager *manager) {
 
     manager->priv->active = TRUE;
 
+    windows = add_overlays (manager);
+
     show_windows (manager->priv->windows);
 
+    g_timeout_add (2000,
+                   (GSourceFunc)remove_overlays,
+                   windows);
+
     return TRUE;
 }
 
@@ -1218,12 +1332,17 @@ gs_manager_request_unlock (GSManager *manager) {
     }
 
     if (manager->priv->windows == NULL) {
-        gs_debug ("We don't have any windows!");
+        gs_debug ("Request unlock but we don't have any windows!");
         return FALSE;
     }
 
     /* Find the GSWindow that contains the pointer */
     window = find_window_at_pointer (manager);
+    if (window == NULL) {
+        gs_debug ("Request unlock but no window could be found!");
+        return FALSE;
+    }
+
     gs_window_request_unlock (window);
 
     return TRUE;
