@@ -144,6 +144,30 @@ _gs_prefs_set_cycle_timeout (GSPrefs *prefs,
     prefs->cycle = value * 60000;
 }
 
+static void
+_gs_prefs_set_dpms_sleep_timeout (GSPrefs *prefs,
+                                  int      value) {
+    if (value < 0)
+        value = 0;
+
+    if (value > 60)
+        value = 60;
+
+    prefs->dpms_sleep_timeout = value;
+}
+
+static void
+_gs_prefs_set_dpms_off_timeout (GSPrefs *prefs,
+                                int      value) {
+    if (value < 0)
+        value = 0;
+
+    if (value > 60)
+        value = 60;
+
+    prefs->dpms_off_timeout = value;
+}
+
 static void
 _gs_prefs_set_mode (GSPrefs    *prefs,
                     gint        mode) {
@@ -220,6 +244,12 @@ _gs_prefs_set_lock_with_saver_enabled (GSPrefs  *prefs,
     prefs->lock_with_saver_enabled = value;
 }
 
+static void
+_gs_prefs_set_fullscreen_inhibit (GSPrefs *prefs,
+                                  gboolean value) {
+    prefs->fullscreen_inhibit = value;
+}
+
 static void
 _gs_prefs_set_keyboard_enabled (GSPrefs  *prefs,
                                 gboolean  value) {
@@ -328,6 +358,11 @@ gs_prefs_load_from_settings (GSPrefs *prefs) {
                                     DEFAULT_KEY_IDLE_DELAY);
     _gs_prefs_set_timeout (prefs, value);
 
+    bvalue = xfconf_channel_get_bool (prefs->priv->channel,
+                                      KEY_FULLSCREEN_INHIBIT,
+                                      DEFAULT_KEY_FULLSCREEN_INHIBIT);
+    _gs_prefs_set_fullscreen_inhibit (prefs, bvalue);
+
     value = xfconf_channel_get_int (prefs->priv->channel,
                                     KEY_LOCK_WITH_SAVER_DELAY,
                                     DEFAULT_KEY_LOCK_WITH_SAVER_DELAY);
@@ -338,6 +373,16 @@ gs_prefs_load_from_settings (GSPrefs *prefs) {
                                     DEFAULT_KEY_CYCLE_DELAY);
     _gs_prefs_set_cycle_timeout (prefs, value);
 
+    value = xfconf_channel_get_double (prefs->priv->channel,
+                                       KEY_DPMS_SLEEP_AFTER,
+                                       DEFAULT_KEY_DPMS_SLEEP_AFTER);
+    _gs_prefs_set_dpms_sleep_timeout (prefs, (int)value);
+
+    value = xfconf_channel_get_double (prefs->priv->channel,
+                                       KEY_DPMS_OFF_AFTER,
+                                       DEFAULT_KEY_DPMS_OFF_AFTER);
+    _gs_prefs_set_dpms_off_timeout (prefs, (int)value);
+
     mode = xfconf_channel_get_int (prefs->priv->channel,
                                    KEY_MODE,
                                    DEFAULT_KEY_MODE);
@@ -464,11 +509,26 @@ key_changed_cb (XfconfChannel *channel,
 
         enabled = xfconf_channel_get_bool (channel, property, DEFAULT_KEY_LOCK_WITH_SAVER_ENABLED);
         _gs_prefs_set_lock_with_saver_enabled (prefs, enabled);
+    } else if (strcmp (property, KEY_FULLSCREEN_INHIBIT) == 0) {
+        gboolean enabled;
+
+        enabled = xfconf_channel_get_bool (channel, property, DEFAULT_KEY_FULLSCREEN_INHIBIT);
+        _gs_prefs_set_fullscreen_inhibit (prefs, enabled);
     } else if (strcmp (property, KEY_CYCLE_DELAY) == 0) {
         int delay;
 
         delay = xfconf_channel_get_int (channel, property, DEFAULT_KEY_CYCLE_DELAY);
         _gs_prefs_set_cycle_timeout (prefs, delay);
+    } else if (strcmp (property, KEY_DPMS_SLEEP_AFTER) == 0) {
+        double delay;
+
+        delay = xfconf_channel_get_double (channel, property, DEFAULT_KEY_DPMS_SLEEP_AFTER);
+        _gs_prefs_set_dpms_sleep_timeout (prefs, (int)delay);
+    } else if (strcmp (property, KEY_DPMS_OFF_AFTER) == 0) {
+        double delay;
+
+        delay = xfconf_channel_get_double (channel, property, DEFAULT_KEY_DPMS_OFF_AFTER);
+        _gs_prefs_set_dpms_off_timeout (prefs, (int)delay);
     } else if (strcmp (property, KEY_KEYBOARD_ENABLED) == 0) {
         gboolean enabled;
 
@@ -536,6 +596,7 @@ gs_prefs_init (GSPrefs *prefs) {
     prefs->idle_activation_enabled  = TRUE;
     prefs->sleep_activation_enabled = TRUE;
     prefs->lock_with_saver_enabled  = TRUE;
+    prefs->fullscreen_inhibit       = FALSE;
     prefs->logout_enabled           = FALSE;
     prefs->user_switch_enabled      = FALSE;
 
