@@ -1602,6 +1602,10 @@ gs_window_set_lock_active (GSWindow *window,
                            gboolean  active) {
     g_return_if_fail (GS_IS_WINDOW (window));
 
+    if (window->priv->lock_active == active) {
+        return;
+    }
+
     gs_debug("Setting lock active: %i", active);
 
     window->priv->lock_active = active;
@@ -1894,6 +1898,12 @@ gs_window_real_get_preferred_height (GtkWidget *widget,
     *minimal_height = *natural_height = requisition.height;
 }
 
+void
+gs_window_reposition (GSWindow *window) {
+    GtkRequisition requisition;
+    gs_window_real_size_request (GTK_WIDGET (window), &requisition);
+}
+
 static gboolean
 gs_window_real_grab_broken (GtkWidget          *widget,
                             GdkEventGrabBroken *event) {
