@@ -103,6 +103,7 @@ static GOptionEntry entries[] = {
 };
 
 static GMainLoop *loop = NULL;
+int return_code = 0;
 
 static GDBusMessage *
 screensaver_send_message (GDBusConnection *conn,
@@ -180,6 +181,7 @@ do_command (GDBusConnection *conn) {
 
     if (!screensaver_is_running (conn)) {
         g_message ("Screensaver is not running! Start xfce4-screensaver first");
+        return_code = 1;
         goto done;
     }
 
@@ -211,18 +213,18 @@ do_command (GDBusConnection *conn) {
             goto done;
         }
         body = g_dbus_message_get_body (reply);
-        g_object_unref (reply);
+        g_variant_get (body, "(as)", &iter);
 
-        if (g_variant_n_children(body) <= 0) {
+        if (g_variant_iter_n_children(iter) <= 0) {
             g_print (_("The screensaver is not inhibited\n"));
         } else {
-            g_variant_get (body, "s", &iter);
             g_print (_("The screensaver is being inhibited by:\n"));
             while (g_variant_iter_loop (iter, "s", &str)) {
                 g_print ("\t%s\n", str);
             }
-            g_variant_iter_free (iter);
         }
+        g_variant_iter_free (iter);
+        g_object_unref (reply);
     }
 
     if (do_time) {
@@ -325,5 +327,5 @@ main (int    argc,
     loop = g_main_loop_new (NULL, FALSE);
     g_main_loop_run (loop);
     g_object_unref (conn);
-    return 0;
+    exit (return_code);
 }
